@@ -1,34 +1,32 @@
 from math import ceil, floor
 from time import localtime
 
-from threp.utils import unsigned_int, unsigned_char, float
+from threp.utils import unsigned_int, unsigned_char, float_
 from threp.common import decode, decompress, entry
 from threp.static import work_attr, skeys, kkeys, oldwork_magicnumber_flc
-from threp.type import *
+from threp.type import get_alltypes, format_types
 
 def threp_decodedata(buffer):
     work_magicnumber = unsigned_int(buffer, 0)
     if work_magicnumber in oldwork_magicnumber_flc:
         return oldworkrep_cut(oldwork_magicnumber_flc[work_magicnumber], buffer)
-    else:
-        is_2hu_replay = False
-        for key, value in work_attr.items():
-            if work_magicnumber == value['magic_number']:
-                is_2hu_replay = True
-                work = key
-        if is_2hu_replay:
-            length = unsigned_int(buffer, 0x1c)
-            dlength = unsigned_int(buffer, 0x20)
-            decodedata = bytearray(dlength)
-            rawdata = bytearray(buffer[0x24:])
-            decode(rawdata, length, work_attr[work]['decode_var1'], work_attr[work]['decode_var2'],
-                   work_attr[work]['decode_var3'])
-            decode(rawdata, length, work_attr[work]['decode_var4'], work_attr[work]['decode_var5'],
-                   work_attr[work]['decode_var6'])
-            decompress(rawdata, decodedata, length)
-            return decodedata, work
-        else:
-            raise Exception("Bad file magic number")
+    is_2hu_replay = False
+    for key, value in work_attr.items():
+        if work_magicnumber == value['magic_number']:
+            is_2hu_replay = True
+            work = key
+    if is_2hu_replay:
+        length = unsigned_int(buffer, 0x1c)
+        dlength = unsigned_int(buffer, 0x20)
+        decodedata = bytearray(dlength)
+        rawdata = bytearray(buffer[0x24:])
+        decode(rawdata, length, work_attr[work]['decode_var1'], work_attr[work]['decode_var2'],
+               work_attr[work]['decode_var3'])
+        decode(rawdata, length, work_attr[work]['decode_var4'], work_attr[work]['decode_var5'],
+               work_attr[work]['decode_var6'])
+        decompress(rawdata, decodedata, length)
+        return decodedata, work
+    raise Exception("Bad file magic number")
 
 def threp_cut(decodedata, work, frameignore = False):
     info = {'stages': {}, 'stage': None,
@@ -52,21 +50,15 @@ def threp_cut(decodedata, work, frameignore = False):
     info['clear'] = clear
 
     if work=='95':
-        for i in range(7, 15):
-            info['player'] += chr(unsigned_char(decodedata, i))
-        info['player'] = info['player'].strip()
+        info['player'] = "".join(chr(unsigned_char(decodedata, i)) for i in range(7, 15)).strip()
         info['character'] = 0
     else:
-        for i in range(8):
-            info['player'] += chr(unsigned_char(decodedata, i))
-        info['player'] = info['player'].strip()
+        info['player'] = "".join(chr(unsigned_char(decodedata, i)) for i in range(8)).strip()
 
-    info['slowrate']=round(float(decodedata, work_attr[work]['slowrate']), 2)
-
-    info['date']=str(date[0])+"/"+str(date[1]).zfill(2)+"/"+str(date[2]).zfill(2)+" "+str(date[3]).zfill(2)+":"+str(date[4]).zfill(2)
+    info['slowrate']=round(float_(decodedata, work_attr[work]['slowrate']), 2)
+    info['date'] = f"{date[0]}/{date[1]:02d}/{date[2]:02d} {date[3]:02d}:{date[4]:02d}"
 
     stagedata = work_attr[work]['stagedata']
-
     stagedata_t = work_attr[work]['stagedata'] + work_attr[work]['stagedata_offset']
 
     score = list(range(6))
@@ -85,25 +77,21 @@ def threp_cut(decodedata, work, frameignore = False):
                 pass
             else:
                 if frameignore:
-                    tmp_frame = frame
                     try:
-                        frame = true_frame(llength)
-                    except:
+                        true_frame(llength)
+                    except Exception:
                         # 长度再次出错
-                        frame = correct_true_frame(llength)
+                        correct_true_frame(llength)
                         # 忽略帧数，强制保留单面长度
                         info['error'].append({'type': "length so short error",
-                                              'message': str(i) + "面，读取到的单面长度：" + str(
-                                                  llength) + "，判断为长度出错，尝试自动补正"})
+                                              'message': f"{i}面，读取到的单面长度：{llength}，判断为长度出错，尝试自动补正"})
                     # 忽略帧数，强制保留单面长度
                     info['error'].append({'type': "frame read error",
-                                          'message': str(i) + "面，读取到的单面帧数：" + str(tmp_frame) + "，读取到的单面长度：" + str(
-                                              llength) + "，帧数计算出的单面长度：" + str(tmp_frame * 6 + ceil(tmp_frame / 30)) + "，判断为单面帧数出错"})
+                                          'message': f"{i}面，读取到的单面帧数：{frame}，读取到的单面长度：{llength}，帧数计算出的单面长度：{frame * 6 + ceil(frame / 30)}，判断为单面帧数出错"})
                 else:
                     # rep单面长度出错
                     info['error'].append({'type': "length read error",
-                                          'message': str(i) + "面，读取到的单面帧数：" + str(frame) + "，读取到的单面长度：" + str(
-                                              llength) + "，帧数计算出的单面长度：" + str(frame * 6 + ceil(frame / 30)) + "，判断为单面长度出错"})
+                                          'message': f"{i}面，读取到的单面帧数：{frame}，读取到的单面长度：{llength}，帧数计算出的单面长度：{frame * 6 + ceil(frame / 30)}，判断为单面长度出错"})
                     llength = frame * 6 + ceil(frame / 30)
             stagedata_t += llength + work_attr[work]['replaydata_offset']
             stagedata += work_attr[work]['replaydata_offset'] + llength
@@ -113,9 +101,8 @@ def threp_cut(decodedata, work, frameignore = False):
     stagedata = work_attr[work]['stagedata'] + work_attr[work]['stagedata_offset']
 
     for l in range(stage):
-        stage_info = {'score': None, 'frame': None, 'llength': None, 'faith': None,
-                      'bin': {'header': None, 'replay': None, 'tail': None},
-                      'index': {'header': None, 'replay': None, 'tail': None}}
+        stage_info = {'score': None, 'frame': None,
+                      'replay': {}}
 
         replaydata = stagedata + work_attr[work]['replaydata_offset']
         frame = unsigned_int(decodedata, stagedata + 0x4)
@@ -132,11 +119,7 @@ def threp_cut(decodedata, work, frameignore = False):
             else:
                 if frameignore:
                     # 忽略帧数，强制保留单面长度
-                    try:
-                        frame = true_frame(llength)
-                    except:
-                        # 长度再次出错
-                        frame = correct_true_frame(llength)
+                    frame = correct_true_frame(llength)
                     perframe = 6
                 else:
                     # rep单面长度出错
@@ -145,13 +128,7 @@ def threp_cut(decodedata, work, frameignore = False):
 
         stage_info['score'] = score[l]
         stage_info['frame'] = frame
-        stage_info['llength'] = llength
-        stage_info['bin']['header'] = decodedata[stagedata: replaydata]
-        stage_info['bin']['replay'] = decodedata[replaydata: (replaydata + (frame * perframe))]
-        stage_info['bin']['tail'] = decodedata[(replaydata + (frame * perframe)): (replaydata + llength)]
-        stage_info['index']['header'] = (stagedata, replaydata)
-        stage_info['index']['replay'] = (replaydata, (replaydata + (frame * perframe)))
-        stage_info['index']['tail'] = ((replaydata + (frame * perframe)), (replaydata + llength))
+        stage_info['replay'] = decodedata[replaydata: (replaydata + (frame * perframe))]
 
         info['stages'][l] = stage_info
 
@@ -190,7 +167,7 @@ def hmxrep_cut(dat):
     name = decodedata[0x19:0x19 + 8]
     char = decodedata[0x06]
     rank = decodedata[0x07]
-    drop = float(decodedata, 0x2c)
+    drop = float_(decodedata, 0x2c)
 
     date = date.strip().decode()
     date = f"20{date[6:8]}/{date[:2]}/{date[3:5]}"
@@ -399,7 +376,7 @@ def yymrep_cut(dat):
     name = decodedata[0x5e:0x5e+8]
     char = decodedata[0x56]
     rank = decodedata[0x57]
-    drop = float(decodedata, 0xcc)
+    drop = float_(decodedata, 0xcc)
 
     rep_info['date'] = date.strip().decode()
     rep_info['player'] = name.strip().decode()
@@ -530,7 +507,7 @@ def yycrep_cut(dat):
     name = decodedata[0x72:0x72 + 8]
     char = decodedata[0x6a]
     rank = decodedata[0x6b]
-    drop = float(decodedata, 0x118)
+    drop = float_(decodedata, 0x118)
 
     rep_info['date'] = date.strip().decode()
     rep_info['player'] = name.strip().decode()
@@ -790,46 +767,17 @@ def threp_output(info, work):
 
     output = {}
 
-    if work=='10':
-        character, ctype, rank, clear = th10type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='11':
-        character, ctype, rank, clear = th11type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='12':
-        character, ctype, rank, clear = th12type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='13':
-        character, ctype, rank, clear = th13type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='14':
-        character, ctype, rank, clear = th14type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='15':
-        character, ctype, rank, clear = th15type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='16':
-        character, ctype, rank, clear = th16type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='128':
-        character, ctype, rank, clear = th128type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='125':
-        character, ctype, rank, clear = th125type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='143':
-        character, ctype, rank, clear = th143type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='95':
-        character, ctype, rank, clear = th95type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='165':
-        character, ctype, rank, clear = th165type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='17':
-        character, ctype, rank, clear = th17type(info['character'], info['ctype'], info['rank'], info['clear'])
-    elif work=='18':
-        character, ctype, rank, clear = th18type(info['character'], info['ctype'], info['rank'], info['clear'])
-    else:
-        raise Exception(f"Unrecognized work {work}")
+    character, ctype, rank, clear = get_alltypes(work, info['character'], info['ctype'], info['rank'], info['clear'])
 
-    output['base_info']=' '.join([character, ctype, rank, clear]).strip().replace("  ", " ")
-    output['base_infos']={
+    output['base_info'] = format_types(work, character, ctype, rank, clear)
+    output['base_infos'] = {
         "character": character,
         "shottype": ctype,
         "rank": rank,
         "stage": clear
     }
-    output['stage_score']=[]
-    output['player']=info['player']
+    output['stage_score'] = []
+    output['player'] = info['player']
     output['slowrate'] = info['slowrate']
     output['date'] = info['date']
     output['error'] = info['error']
@@ -857,7 +805,7 @@ def threp_output(info, work):
     if work=='125':
         for l in range(stage):
             stage_info = info['stages'][l]
-            replaydata = stage_info['bin']['replay']
+            replaydata = stage_info['replay']
             replaydata.append(0x00)
             frame = stage_info['frame']
             skey = []
@@ -887,7 +835,7 @@ def threp_output(info, work):
     else:
         for l in range(stage):
             stage_info = info['stages'][l]
-            replaydata = stage_info['bin']['replay']
+            replaydata = stage_info['replay']
             frame = stage_info['frame']
             skey = []
             kkey = []
@@ -950,17 +898,16 @@ def true_frame(llength):
     frame = floor(llength / (6 + 1/30))
     if frame * 6 + ceil(frame / 30) == llength:
         return frame
-    else:
-        # 暴搜，，，
-        for i in range(frame-10, frame+10):
-            if i * 6 + ceil(i / 30) == llength:
-                return i
-        raise Exception("Cant correct the frame length")
+    # 暴搜，，，
+    for i in range(frame - 10, frame + 10):
+        if i * 6 + ceil(i / 30) == llength:
+            return i
+    raise Exception("Can't correct the frame length")
 
 def correct_true_frame(llength):
     try:
         return true_frame(llength)
-    except:
+    except Exception:
         # 一直加65536，直到能够获取正确的帧数
         return correct_true_frame(llength + 65536)
 
@@ -970,7 +917,7 @@ def process_read_error(work, decodedata):
         work = '14'
         try:
             return threp_output(threp_cut(decodedata, work), work)
-        except:
+        except Exception:
             # 庙rep因长度错误被误转换到城
             work = '13'
             return threp_output(threp_cut(decodedata, work, True), work)
@@ -987,14 +934,14 @@ def process_read_error(work, decodedata):
             if check_error(replay_info2, "length read error") and replay_info2['frame_count'] < 54000:
                 return threp_output(threp_cut(decodedata, work, True), work)
             return replay_info2
-        except:
+        except Exception:
             # 庙rep因长度错误被误转换到城
             return threp_output(threp_cut(decodedata, work, True), work)
     else:
         try:
             # 尝试矫正frame长度重试
             return threp_output(threp_cut(decodedata, work, True), work)
-        except:
+        except Exception:
             # 没救了，等死吧
             raise Exception("Failed to open replay file")
 
@@ -1007,6 +954,5 @@ def load(file):
             return decodedata
         replay_info = threp_output(threp_cut(decodedata, work), work)
         return replay_info if not replay_info['screen_action'] else process_read_error(work, decodedata)
-    except:
+    except Exception:
         return process_read_error(work, decodedata)
-
